/*
 * Pinout from Colecovision:
 * 
 * 1,2:  Ground      GND
 * 3:    D3          45
 * 4:    A14         31
 * 5:    AD4000      13
 * 6:    AD2000      12
 * 7:    HALT        9
 * 8:    WR          7
 * 9:    NMI         5
 * 10:   QUAD        50
 * 11:   BUSRQ       38
 * 12:   D1          43
 * 13:   RESETNOT    53
 * 14:   D0          42
 * 15:   M1          14
 * 16:   D7          49
 * 17:   D6          48
 * 18:   A1          23
 * 19:   D4          46
 * 20:   A2          24
 * 21:   A4          26
 * 22:   A13         32
 * 23:   A5          27
 * 24:   A6          28
 * 25:   A7          29
 * 26:   A8          37
 * 27:   A9          36
 * 28:   A10         35
 * 29:   MEMMAPOVR   20
 * 30:   IOMAPOVR    21
 * 
 * 31:   EXAUD       3
 * 32:   EXVIDEN     A7
 * 33:   EXVID       exvid circuit
 * 34:   EXT_RST     19
 * 35:   PCLK
 * 36:   RESET       52
 * 37:   A11         34
 * 38:   A12         33
 * 39:   VDCRST      15
 * 40:   CLK2        40
 * 41:   NC
 * 42:   NC
 * 43:   A15         30
 * 44:   A3          25
 * 45:   CLK         39
 * 46:   D2          44
 * 47:   A0          22
 * 48:   D5          47
 * 49:   RFSH        2
 * 50:   WAIT        4
 * 51:   INT         51
 * 52:   BUSACK      6
 * 53:   RD          8
 * 54:   MREQ        10
 * 55:   IORQ        11
 * 56:   AUDIOOUT
 * 57:   +12V
 * 58,59: +5
 * 60:   -5V
 * 
 */


#include "tests.h"


void setup() {
  // Serial is 115200 baud.  Because why not?
  Serial.begin( 115200 );

  // Set up the timer for consistent delays
  TCCR1A = 0b00000000;
  TCCR1B = 0b00000001;
  TCCR1C = 0b00000000;
}

uint16_t timer_target;

void resetTimer()
{
  timer_target = 0;
  TCNT1 = 0;
}

void delayClocks( uint16_t clocks )
{
  timer_target += clocks;
  if( TCNT1 + 10 < timer_target )
  {
    TIFR1 |= _BV( OCF1A );
    OCR1A = timer_target;
    while( !( TIFR1 & _BV( OCF1A ) ) );
  }

  timer_target &= 0x7fff;
  TCNT1 = (TCNT1 & 0x7fff) + 7;
}

static int menu()
{
  Serial.print(
    "\n\n\n"
    "Choose a test mode:\n"
    "1)  Basic functionality\n"
    "2)  Memory tests\n"
    "3)  VRAM test\n"
    "4)  Input test\n"
    "5)  External video test\n"
    );
  do {
    int c = Serial.read();
    if( c >= '1' && c <= '5' )
    {
      return c - '0';
    }
  }
  while(true);
}


void loop() {
  // put your main code here, to run repeatedly:
  switch( menu() )
  {
    case 1:
      doBasicTests();
      break;
    case 2:
      doMemTests();
      break;
    case 3:
      vramTest();
      break;
    case 4:
      checkInput();
      break;
    case 5:
      doExtVideoTest();
      break;
  }
}
